PointwiseLoss
=============

.. currentmodule:: pykeen.losses

.. autoclass:: PointwiseLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PointwiseLoss.validate_labels

   .. rubric:: Methods Documentation

   .. automethod:: validate_labels
